@@ -133,7 +133,7 @@ static inline void markov_node_free(struct markov_node *old)
 	free(old);
 }
 
-static void markov_compute(i)
+static void markov_compute(int i)
 {
 	int j;
 	ADJMAP(i,i)=100.0;
@@ -670,7 +670,7 @@ static void splitpacket(const unsigned char *buf,int size,int dir)
 	//fprintf(stderr,"%s: splitpacket rnx=%d remaining=%d size=%d\n",progname,rnx[dir],remaining[dir],size);
 	if (size==0) return;
 	if (rnx[dir]>0) {
-		register int amount=MIN(remaining[dir],size);
+		int amount=MIN(remaining[dir],size);
 		//fprintf(stderr,"%s: fragment amount %d\n",progname,amount);
 		memcpy(fragp[dir],buf,amount);
 		remaining[dir]-=amount;
@@ -813,9 +813,9 @@ static int check_open_fifos_n_plugs(struct pollfd *pfd,int *outfd,char *vdepath[
 static void save_pidfile()
 {
 	if(pidfile[0] != '/')
-		strncat(pidfile_path, pidfile, PATH_MAX - strlen(pidfile_path));
+		strncat(pidfile_path, pidfile, PATH_MAX - strlen(pidfile_path) - 1);
 	else
-		strcpy(pidfile_path, pidfile);
+		strncpy(pidfile_path, pidfile, PATH_MAX - 1);
 
 	int fd = open(pidfile_path,
 			O_WRONLY | O_CREAT | O_EXCL,
@@ -1467,7 +1467,7 @@ int main(int argc,char *argv[])
 
 	while(1) {
 		int c;
-		c = GETOPT_LONG (argc, argv, "hl:n:d:M:D:m:b:s:c:v:L:f:",
+		c = GETOPT_LONG (argc, argv, "hNl:n:d:M:D:m:b:s:c:v:L:f:",
 				long_options, &option_index);
 		if (c<0)
 			break;
@@ -1607,7 +1607,7 @@ int main(int argc,char *argv[])
 
 	/* saves current path in pidfile_path, because otherwise with daemonize() we
 	 * forget it */
-	if(getcwd(pidfile_path, PATH_MAX-1) == NULL) {
+	if(getcwd(pidfile_path, PATH_MAX-2) == NULL) {
 		printlog(LOG_ERR, "getcwd: %s", strerror(errno));
 		exit(1);
 	}
@@ -1679,7 +1679,7 @@ int main(int argc,char *argv[])
 			int mgmtfdstart=consoleindex;
 			if (mgmtindex >= 0) mgmtfdstart=mgmtindex+1;
 			if (mgmtfdstart >= 0 && npfd > mgmtfdstart) {
-				register int i;
+				int i;
 				for (i=mgmtfdstart;i<npfd;i++) {
 					if (pfd[i].revents & POLLIN && mgmtcommand(pfd[i].fd) < 0)
 						pfd[i].revents |= POLLHUP;
